@@ -18,11 +18,11 @@ WWW::Search::AOL - backend for searching search.aol.com
 
 =head1 VERSION
 
-Version 0.0105
+Version 0.0106
 
 =cut
 
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 
 use vars qw(@ISA);
 
@@ -247,7 +247,7 @@ sub preprocess_results_page
 
 =head1 AUTHOR
 
-Shlomi Fish, C<< <shlomif@iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 Funded by L<http://www.deviatemedia.com/> and
 L<http://www.redtreesystems.com/>.
